package net.wanji.opt.service.impl;


import lombok.extern.slf4j.Slf4j;
import net.wanji.common.framework.dubbointerface.impl.BaseDubboInterfaceImpl;
import net.wanji.common.framework.mapper.BaseInterfaceMapper;
import net.wanji.opt.dao.mapper.GreenwaveHistoryMapper;
import net.wanji.opt.dto.report.GreenHistIndexDTO;
import net.wanji.opt.entity.GreenwaveHist;
import net.wanji.opt.service.GreenwaveHistProvider;
import org.apache.dubbo.config.annotation.DubboService;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.util.List;
import java.util.Objects;
import java.util.stream.Collectors;
import java.util.stream.Stream;


/**
 * <p>
 * 绿波历史数据
 * </p>
 *
 * @Author fengyi
 * @Date 2024-11-18
 */
@Slf4j
@Component
@DubboService
public class GreenwaveHistProviderImpl extends BaseDubboInterfaceImpl<GreenwaveHist> implements GreenwaveHistProvider {

    @Resource
    private GreenwaveHistoryMapper greenwaveHistoryMapper;


    @Value("${data.mock.flag}")
    private boolean mockFlag;

    @Override
    public BaseInterfaceMapper<GreenwaveHist> getBaseInterfaceMapper() {
        return this.greenwaveHistoryMapper;
    }

    @Override
    public GreenHistIndexDTO findGreenIndexByDateScope(Integer greenId, String startDate, String endDate) {
        List<GreenHistIndexDTO> list = greenwaveHistoryMapper.findGreenIndexByDateScope(greenId,startDate,endDate);
        if (!list.isEmpty()) {
            GreenHistIndexDTO dto = list.get(0);
            String flowAll = dto.getFlowAll();
            if (Objects.nonNull(flowAll)) {
                List<Integer> flowList = Stream.of(flowAll.split(",")).map(Integer::parseInt).collect(Collectors.toList());
                int capacity = 0;
                //每3个连续5分钟流量和*4规约为小时流量
                for (int i = 0; i <= flowList.size() - 3; i++) {
                    int sum = flowList.get(i) + flowList.get(i + 1) + flowList.get(i + 2);
                    if (sum * 4 > capacity) {
                        capacity = sum * 4;
                    }
                }
                dto.setCapacity(capacity);
                return dto;
            }
        }
        return null;
    }

}
